==> finely-1.0.0.tar.gz: finely-1.0.0/README.md <==
# Finely - Personal Finance Tracker 💥

<img src="finely/assets/icon/icon-tra.png" width="100">

Listen up, you primitive money-grubbing meatbags! **Finely** is the most _insanely_ badass desktop app for wrestling your pathetic Earth credits into submission. Built with Flet and Python, it’s got a _sick dark mode_ and a UI so slick it’ll make your brain short-circuit. Your data? **Now safely stored in your OS’s sacred user directory** — no more fragile `data.json` floating next to the code. Clouds? Pfft, we don’t trust that garbage. Take control of your cash or get schwifty trying.

![Finely Dashboard](finely/assets/screenshots/dashboard.jpg)![Finely Reports](finely/assets/screenshots/reports.jpg)\
_Bow before its cosmic glory, you financial plebs._

---

## ✨ Features That’ll Melt Your Tiny Brain

- **📊 Dashboard of Total Annihilation**: Real-time income, expenses, and net balance stats in glorious dark mode. Face your monetary screw-ups head-on!
- **📈 Charts That Break Reality**: Pie charts slice your spending like a plasma blade, bar charts pit months against each other like gladiators in a time rift, and line charts track your net worth like it’s spiraling into a black hole.
- **🖤 Dark Mode That Screams Genius**: Sleek, mind-bending, and easier on your weak human eyes than a supernova.
- **💾 Data Vault of Doom (Upgraded!)** Survives code updates, folder moves, and even alien invasions.
- **📦 Runs on Your Junk OS**: Windows, macOS, Linux. Snag the installer and dominate without a PhD in Python.
- **🔧 Customize Like a Mad Scientist**: Tweak categories in-app to bend this app to your will. It’s your financial multiverse now.
- **⚡ Run Anywhere with `finely`**: After install, just type `finely` in your terminal — no matter where you are.

---

## 🚀 Fire Up This Monster

### 🧠 Hack It (For Devs & Terminal Wizards)

```bash
git clone https://github.com/AmirAnsarpour/Finely.git
cd Finely
pip install .
finely
```

_✅ Installs as a real Python package.
✅ Creates finely command globally.
✅ Data saved safely in user directory — not next to code!_

## 🗃️ Where’s My Precious Data?

Finely no longer trusts your chaotic project folder. Your financial empire is now stored in:

Windows: C:\Users\<You>\AppData\Roaming\Finely\data.json
macOS: ~/Library/Application Support/Finely/data.json
Linux: ~/.local/share/Finely/data.json

_💡 Want to migrate old data.json? Just copy it to the new path above — Finely won’t even notice you cheated._

## 🤝 Join the Cosmic Cash Rebellion

Finely’s a frickin’ masterpiece, but it’s begging for more chaos. Got the stones to make it legendary? Jump in or get lost in a wormhole.

1. 🔍 Report Bugs: Spot a glitch? Scream about it in Issues with details or buzz off.
2. 💡 Cook Up Insane Ideas: New charts, budgeting death rays, export portals? Rant in Discussions.
3. 👨‍💻 Code Like a Freakin’ Deity: Fix, tweak, or unleash madness. PRs welcome — guidelines coming when I feel like it.
4. 🎨 Design Like a Psycho Artist: Make the UI even more mind-bending. Dark mode’s just the appetizer.
5. 🌌 Conquer Alien Economies: Translate Finely for every species in the multiverse.

   _Let’s turn this into the ultimate money-destroying machine. Riches beyond your puny comprehension await!_

==> finely-1.0.2.tar.gz: finely-1.0.2/README.md <==
# Finely - Personal Finance Tracker 💥

<img src="https://github.com/AmirAnsarpour/Finely/raw/main/finely/assets/icon/icon-tra.png" width="100">

Listen up, you primitive money-grubbing meatbags! **Finely** is the most _insanely_ badass desktop app for wrestling your pathetic Earth credits into submission. Built with Flet and Python, it’s got a _sick dark mode_ and a UI so slick it’ll make your brain short-circuit. Your data? **Now safely stored in your OS’s sacred user directory** — no more fragile `data.json` floating next to the code. Clouds? Pfft, we don’t trust that garbage. Take control of your cash or get schwifty trying.

![Finely Dashboard](https://github.com/AmirAnsarpour/Finely/raw/main/finely/assets/screenshots/dashboard.jpg)![Finely Reports](https://github.com/AmirAnsarpour/Finely/raw/main/finely/assets/screenshots/reports.jpg)\
_Bow before its cosmic glory, you financial plebs._

---

## ✨ Features That’ll Melt Your Tiny Brain

- **📊 Dashboard of Total Annihilation**: Real-time income, expenses, and net balance stats in glorious dark mode. Face your monetary screw-ups head-on!
- **📈 Charts That Break Reality**: Pie charts slice your spending like a plasma blade, bar charts pit months against each other like gladiators in a time rift, and line charts track your net worth like it’s spiraling into a black hole.
- **🖤 Dark Mode That Screams Genius**: Sleek, mind-bending, and easier on your weak human eyes than a supernova.
- **💾 Data Vault of Doom (Upgraded!)** Survives code updates, folder moves, and even alien invasions.
- **📦 Runs on Your Junk OS**: Windows, macOS, Linux. Snag the installer and dominate without a PhD in Python.
- **🔧 Customize Like a Mad Scientist**: Tweak categories in-app to bend this app to your will. It’s your financial multiverse now.
- **⚡ Run Anywhere with `finely`**: After install, just type `finely` in your terminal — no matter where you are.

---

## 🚀 Fire Up This Monster

### 🧠 Hack It (For Devs & Terminal Wizards)

```bash
pip install finely
finely
```

_✅ Installs as a real Python package.
✅ Creates finely command globally.
✅ Data saved safely in user directory — not next to code!_

## 🗃️ Where’s My Precious Data?

Finely no longer trusts your chaotic project folder. Your financial empire is now stored in:

Windows: C:\Users\<You>\AppData\Roaming\Finely\data.json
macOS: ~/Library/Application Support/Finely/data.json
Linux: ~/.local/share/Finely/data.json

_💡 Want to migrate old data.json? Just copy it to the new path above — Finely won’t even notice you cheated._

## 🤝 Join the Cosmic Cash Rebellion

Finely’s a frickin’ masterpiece, but it’s begging for more chaos. Got the stones to make it legendary? Jump in or get lost in a wormhole.

1. 🔍 Report Bugs: Spot a glitch? Scream about it in Issues with details or buzz off.
2. 💡 Cook Up Insane Ideas: New charts, budgeting death rays, export portals? Rant in Discussions.
3. 👨‍💻 Code Like a Freakin’ Deity: Fix, tweak, or unleash madness. PRs welcome — guidelines coming when I feel like it.
4. 🎨 Design Like a Psycho Artist: Make the UI even more mind-bending. Dark mode’s just the appetizer.
5. 🌌 Conquer Alien Economies: Translate Finely for every species in the multiverse.

   _Let’s turn this into the ultimate money-destroying machine. Riches beyond your puny comprehension await!_
